<?php
/**
 * $Horde: vacation/index.php,v 1.1.1.1.2.8 2004/03/26 22:43:30 jan Exp $
 *
 * Copyright 2001-2004 Eric Rostetter <eric.rostetter@physics.utexas.edu>
 *
 * See the enclosed file LICENSE for license information (BSD). If you
 * did not receive this file, see http://www.horde.org/bsdl.php.
 */

define('VACATION_BASE', dirname(__FILE__));
$vacation_configured = (@is_readable(VACATION_BASE . '/config/conf.php'));

if ($vacation_configured) {
    include_once VACATION_BASE . '/lib/base.php';
    $uri = 'main.php';
    if (!empty($_SERVER['QUERY_STRING'])) {
       $uri .= '?' . $_SERVER['QUERY_STRING'];
    }
    header('Location: ' . Horde::applicationUrl($uri, true));
    exit;
} else {
    /* vacation isn't configured */
    $title = 'Vacation module is not fully configured.';
    include VACATION_BASE . '/templates/index/notconfigured.inc';
}

?>
